use serde::{Deserialize, Serialize};
use serde_json::Error;
use std::string::String;
use std::{fs::File, io::Read};
use clap::{App, Arg, ArgMatches};

#[derive(Debug, Deserialize, Serialize)]
pub struct Config {
    pub server: String,
    pub username: String,
    pub password: String,
    pub authtoken: Option<String>,
    pub limit: Option<i64>,
}

impl Config {
    pub fn new() -> Self {
        Self {
            server: String::from("https://zabbix.acme.com/api_jsonrpc.php"),
            username: String::from("bob"),
            password: String::from("password"),
            authtoken: Some(String::from("token")),
            limit: Some(20i64)
        }
    }

    pub fn load<'a>(&mut self, configfile: &'a str) {
        let fileopen: Result<File,std::io::Error>;
        let filemeta = std::fs::metadata(configfile);
        let fileexists = match filemeta {
            Ok(_) => true,
            Err(_err) => false,
        };

        if !fileexists {
            let _a = File::create(configfile);
        }
        fileopen = File::open(configfile);

        let mut file = match fileopen {
            Ok(f) => f,
            Err(e) => {
                panic!("{}", e);
            },
        };
        let mut contents = String::new();
        file.read_to_string(&mut contents).unwrap();
        let parse: Result<Config, Error> = serde_json::from_str(contents.as_str());
        let cfg = match parse {
            Ok(cfg) => cfg,
            Err(_e) => Config::new(),
        };
        *self = cfg;
        self.save(configfile);
    }

    pub fn save<'a>(&self, configfile: &'a str) {
        let file = File::create(configfile).unwrap();
        serde_json::to_writer_pretty(file, &self).unwrap();
    }
}

pub fn argparse<'a>() -> ArgMatches<'a> {
            App::new("Zabbix Launch")
                            .version("1.0")
                            .author("PaulBSD <paul@paulbsd.com>")
                            .about("Lights up Launchpad mini using Zabbix data")
                            .arg(Arg::with_name("config")
                                .short("c")
                                .long("config")
                                .value_name("FILE")
                                .help("Sets a custom config file")
                                .takes_value(true))
                            .get_matches()
}