use crate::config::Config;
use serde_json::{json, Value};

const zabbix_api_version: &'static str = "2.0";

pub fn get_zabbix_authtoken(cfg: &mut Config) {
    let body = query_auth_token(&cfg.username, &cfg.password);
    let response = reqwest::blocking::Client::new()
        .post(&cfg.server)
        .json(&body)
        .send()
        .unwrap();

    let values: Value = response.json().unwrap();
    cfg.authtoken = Some(values["result"].as_str().unwrap().to_string());
}

pub fn get_zabbix_problems(cfg: &mut Config) {
    let body = query_problems(&cfg.authtoken.as_ref().unwrap_or(&String::from("")),
                                    cfg.limit.unwrap());
    let response = reqwest::blocking::Client::new()
        .post(&cfg.server)
        .json(&body)
        .send()
        .unwrap();

    let _values: Value = response.json().unwrap();
    // for i in values["result"].as_array().unwrap() {
    //     println!("{}", i);
    // }
}

pub fn query_auth_token(zabbix_username: &String,
                        zabbix_password: &String) -> Value {
    let api_function = "user.login";
    let api_id = 1;
    json!({
        "jsonrpc": zabbix_api_version,
        "method": api_function,
        "params": {
            "user": zabbix_username,
            "password": zabbix_password
        },
        "id": api_id
    })
}

pub fn query_problems(zabbix_token: &String,
                      zabbix_limit: i64) -> Value {
    let zabbix_api_function = "problem.get";
    let zabbix_api_id = 1;
    json!({
        "jsonrpc": zabbix_api_version,
        "method": zabbix_api_function,
        "params": {
            "output": "extend",
            "selectAcknowledges": "extend",
            "selectTags": "extend",
            "selectSuppressionData": "extend",
            "recent": "true",
            "sortfield": ["eventid"],
            "sortorder": "DESC",
            "limit": zabbix_limit
        },
        "auth": zabbix_token,
        "id": zabbix_api_id
    })
}